@@ -277,4 +277,8 @@ domAddNewChild( xmlNodePtr self, xmlChar* nsURI, xmlChar* name );
 
 DLLEXPORT xmlChar* domFailure(xmlNodePtr);
 
+DLLEXPORT xmlChar* domUniqueKey(void*);
+
+DLLEXPORT int domIsSameNode(void*, void *);
+
 #endif
